/*
 * This Source Code Form is subject to the terms of the Mozilla Public License,
 * v. 2.0. If a copy of the MPL was not distributed with this file, You can
 * obtain one at https://mozilla.org/MPL/2.0/.
 */

import { expect, test } from '@playwright/test';

test('desktop page has nav tree', async ({ page }) => {
  await page.goto('/');
  await expect(page.getByRole('navigation')).toBeVisible();
});

test('desktop page does not have nav toggle', async ({ page }) => {
  await page.goto('/');
  await expect(page.getByRole('navigation').getByRole('button')).toBeHidden();
});

test('desktop page has two-column layout', async ({ page }) => {
  await page.goto('/');
  await expect(page.getByTestId('content-pane')).toBeVisible();
  await expect(page.getByTestId('preview-pane')).toBeVisible();
});

test('desktop page has no "preview" nav item', async ({ page }) => {
  await page.goto('/');
  await expect(page.getByRole('tab').filter({ hasText: 'preview' })).toBeHidden();
});
